@@ -27,8 +27,10 @@
 
 typedef enum {
     YELP_RRN_TYPE_DOC = 0,
+    YELP_RRN_TYPE_MAL,
     YELP_RRN_TYPE_MAN,
     YELP_RRN_TYPE_INFO,
+    YELP_RRN_TYPE_TEXT,
     YELP_RRN_TYPE_HTML,
     YELP_RRN_TYPE_XHTML,
     YELP_RRN_TYPE_TOC,
